@@ -1,9 +1,9 @@
 /*
- * @(#)display.c	1.62 11/14/93
+ * @(#)display.c	1.65 1/11/94
  *
  * display.c - update the status indicators and other display elements.
  */
-static char *ident = "@(#)display.c	1.62 11/14/93";
+static char *ident = "@(#)display.c	1.65 1/11/94";
 
 #include <stdio.h>
 #include <sys/param.h>
@@ -43,7 +43,8 @@ extern plpopup_objects	*Workman_plpopup;
 
 extern int num_names, num_nalloc;
 extern int cur_track, cur_pos_abs, cur_pos_rel, cur_tracklen, cur_cdlen,
-	cur_cdmode, cur_ntracks, cur_nsections, cur_lasttrack;
+	cur_ntracks, cur_nsections, cur_lasttrack;
+extern enum cd_modes cur_cdmode;
 extern int cur_frame;
 extern char *cur_cdname, *cur_artist;
 extern int displayed_track, pop_track, *pop_list, pop_listsize, pl_item,
@@ -200,7 +201,7 @@ set_trackname(y, tnum, name, bold)
 	 */
 	if ((int) xv_get(tracknames[*tnum], XV_WIDTH) > maxwidth)
 	{
-		i = strlen(name) / 2;
+		i = (int) strlen(name) / 2;
 		jump = i / 2 + 1;
 
 		while (jump > 0)
@@ -307,7 +308,7 @@ split_trackname(name, artist, nartist, cdname, ncdname, title, ntitle, spec)
 			 * begin with.
 			 */
 			*list = (char **) malloc(sizeof (char *) *
-				(strlen(name) / 2 + 1));
+				((int) strlen(name) / 2 + 1));
 
 			/*
 			 * Each array's first element is really a pointer
@@ -634,11 +635,11 @@ show_stats(ip)
 window1_objects *ip;
 {
 	static char	trk_time[6], abs_time[6];
-	static int	old_cdmode = -1;
+	static enum cd_modes	old_cdmode = UNKNOWN;
 	int		pos;
 
 /* If we're on a different track than we used to be, update the track info */
-	if (displayed_track != cur_track && cur_cdmode != 5)
+	if (displayed_track != cur_track && cur_cdmode != EJECTED)
 		new_track(ip);
 
 /* Update the current play mode */
@@ -706,12 +707,12 @@ window1_objects *ip;
 					TRUE, NULL);
 		}
 
-	if (xv_get(Workman_goodies->a, PANEL_INACTIVE) == (cur_cdmode == 1 ||
-		cur_cdmode == 3))
+	if (xv_get(Workman_goodies->a, PANEL_INACTIVE) ==
+	    (cur_cdmode == PLAYING || cur_cdmode == PAUSED))
 	{
-		xv_set(Workman_goodies->a, PANEL_INACTIVE, cur_cdmode != 1 &&
-			cur_cdmode != 3, NULL);
-		if (cur_cdmode != 1 && cur_cdmode != 3)
+		xv_set(Workman_goodies->a, PANEL_INACTIVE,
+		       cur_cdmode != PLAYING && cur_cdmode != PAUSED, NULL);
+		if (cur_cdmode != PLAYING && cur_cdmode != PAUSED)
 			xv_set(Workman_goodies->b, PANEL_INACTIVE, TRUE, NULL);
 	}
 }
@@ -851,9 +852,7 @@ window1_objects *ip;
 	for (i = 0; i < num_nalloc; i++)
 		if (tracknames[i] != XV_NULL)
 			xv_set(tracknames[i], PANEL_INACTIVE, FALSE, NULL);
-#ifndef hpux
 	xv_set(ip->volume, PANEL_INACTIVE, FALSE, NULL);
-#endif
 	xv_set(ip->songpos, PANEL_INACTIVE, FALSE, NULL);
 	update_title(pu->cdname, NULL);
 	xv_set(pu->tracklist, PANEL_INACTIVE, FALSE, NULL);
@@ -864,12 +863,10 @@ window1_objects *ip;
 	xv_set(pl->playlists, PANEL_INACTIVE, FALSE, NULL);
 	xv_set(pl->listname, PANEL_INACTIVE, FALSE, NULL);
 	xv_set(pl->button7, PANEL_INACTIVE, FALSE, NULL);
-#ifndef hpux
 	xv_set(pu->whichvolume, PANEL_INACTIVE, FALSE, NULL);
 	xv_set(pu->defaultvolume, PANEL_INACTIVE, FALSE, NULL);
 	xv_set(pu->defaultspeaker, PANEL_INACTIVE, FALSE, NULL);
 	xv_set(Workman_goodies->balance, PANEL_INACTIVE, FALSE, NULL);
-#endif
 	xv_set(Workman_goodies->indexscan, PANEL_INACTIVE, FALSE, NULL);
 	xv_set(pu->playmode, PANEL_INACTIVE, FALSE, NULL);
 	xv_set(pu->button1, PANEL_INACTIVE, FALSE, NULL);
@@ -910,7 +907,7 @@ window1_objects *ip;
 	xv_set(pu->playmode, PANEL_VALUE, get_playmode(), NULL);
 
 	displayed_track = -1;
-	cur_cdmode = 4;
+	cur_cdmode = STOPPED;
 }
 
 /*
@@ -1051,7 +1048,7 @@ check_open(f, event, arg, type)
 		xv_set(Workman_window1->songpos, PANEL_VALUE, cur_pos_rel,
 			NULL);
 
-		if (dont_retry && cur_cdmode == 5)
+		if (dont_retry && cur_cdmode == EJECTED)
 		{
 			old_retry = dont_retry;
 			dont_retry = 0;
