@@ -18,7 +18,11 @@ static char *ident = "@(#)plat_linux.c	1.8 5/14/94";
 
 #include "struct.h"
 
-#define DEFAULT_CD_DEVICE	"/dev/cdrom"
+#ifdef SBPCD_HACK
+#define DEFAULT_CD_DEVICE	"/dev/sbpcd"
+#else
+#define DEFAULT_CD_DEVICE	"/dev/sr0"
+#endif
 
 #define max(a,b) ((a) > (b) ? (a) : (b))
  
@@ -113,16 +117,27 @@ gen_get_drive_status(d, oldmode, mode, pos, track, index)
 	enum cd_modes	oldmode, *mode;
 	int		*pos, *track, *index;
 {
+#ifdef SBPCD_HACK
+	static int	endcounter;
+#endif
 	struct cdrom_subchnl		sc;
 	struct itimerval		old_timer, new_timer;
 
+#ifdef SBPCD_HACK
+	static int prevpos = 0;
+#endif
+	
 	/* If we can't get status, the CD is ejected, so default to that. */
 	*mode = EJECTED;
 
 	/* Is the device open? */
 	if (d->fd < 0)
 	{
+#ifdef SBPCD_HACK
+		switch (wmcd_open(d,0)) {
+#else
 		switch (wmcd_open(d)) {
+#endif
 		case -1:	/* error */
 			return (-1);
 
@@ -144,6 +159,29 @@ gen_get_drive_status(d, oldmode, mode, pos, track, index)
 		*pos = sc.cdsc_absaddr.msf.minute * 60 * 75 +
 			sc.cdsc_absaddr.msf.second * 75 +
 			sc.cdsc_absaddr.msf.frame;
+#ifdef SBPCD_HACK
+		if( *pos < prevpos )
+                  {
+                    if( (prevpos - *pos) < 75 )
+                      {
+                      	endcounter++;		/* count occurrences in */
+                      	if( endcounter > 2 )    /* case the user used   */
+                      	  {                     /* the pos. slider      */
+                            *mode = TRACK_DONE;
+                            endcounter = 0;
+                          }
+                      }
+                  }
+                else
+                  /* reset on normal play (timeout: 25 frames)   */
+                  /* WARNING: This may be machine-dependent!     */
+                  /* usually, WorkMan plays ~38 frames per check */
+                  /* on very slow machines this may not be right */
+		  if( abs(prevpos - *pos) > 25 )
+		    endcounter = 0;
+                  
+                prevpos = *pos;
+#endif
 		break;
 
 	case CDROM_AUDIO_PAUSED:
@@ -407,10 +445,19 @@ wm_scsi(d, cdb, cdblen, retbuf, retbuflen, getreply)
 
 /*
  * Open the CD device and figure out what kind of drive is attached.
+ * new parameter "i" introduced for Linux platform with some special drivers
+ * inserted by milliByte@DeathsDoor.com 1997-06-10
  */
 int
+#ifdef SBPCD_HACK
+wmcd_open(d, i)
+#else
 wmcd_open(d)
+#endif
 	struct wm_drive	*d;
+#ifdef SBPCD_HACK
+	int i;
+#endif
 {
 	int		fd;
 	static int	warned = 0;
@@ -423,9 +470,14 @@ wmcd_open(d)
 		cd_device = DEFAULT_CD_DEVICE;
 
 	if (d->fd >= 0)		/* Device already open? */
+#ifdef SBPCD_HACK
+             if( i == 1)     /* ... but re-open it, please */
+                close( d->fd );
+             else
+#endif
 		return (0);
 	
-	d->fd = open(cd_device, 0);
+	d->fd = open(cd_device, O_RDONLY | O_NONBLOCK);
 	if (d->fd < 0)
 	{
 		if (errno == EACCES)
