@@ -4,7 +4,7 @@
 #include <xview/svrimage.h>
 #include "workman_ui.h"
 
-static char *ident = "@(#)setup.c	1.23 1/30/94";
+static char *ident = "@(#)setup.c	1.29 04 Jun 1995";
 
 /*
  * Define a few macros to make relative positioning easier.
@@ -22,7 +22,8 @@ static char *ident = "@(#)setup.c	1.23 1/30/94";
 #define center_y(t, s) xv_set(t, XV_Y, (top(s) + bot(s) - hei(t)) / 2, NULL)
 
 extern void change_track(),
-	window1_button2_notify_callback(),
+	show_cdinfo(),
+	show_db_prefs(),
 	window1_button3_notify_callback(),
 	window1_button4_notify_callback(),
 	popup1_buttonpl_notify_callback(),
@@ -42,13 +43,11 @@ int	basic_spacing = 0;
 int	small_buttons = -1;
 int	big_spaces = 0;		/* Flag: spaces are as big as digits */
 
-static unsigned short bits[] = {
-#include "bitmaps/icon"
-};
-
 /* Make the window a particular size initially so we can position it. */
 #define Dft_Size 50
 
+#include "bitmaps/icon"
+
 /*
  * Create the main window and its contents.
  */
@@ -64,45 +63,30 @@ window1_objects_init(ip, owner)
 	Xv_Screen	screen;
 	Panel_item	item;
 	int		space, screen_no, swidth, sheight, x;
-	static unsigned short mask_bits[] = {
 #include "bitmaps/iconmask"
-	}, speaker_bits[] = {
 #include "bitmaps/loud.icon"
-	}, mode_bits0[] = {
 #include "bitmaps/rew.button"
-	}, mode_bits1[] = {
 #include "bitmaps/play.button"
-	}, mode_bits2[] = {
 #include "bitmaps/ff.button"
-	}, mode_bits3[] = {
 #include "bitmaps/pause.button"
-	}, mode_bits4[] = {
 #include "bitmaps/stop.button"
-	}, mode_bits5[] = {
 #include "bitmaps/eject.button"
-	}, small_bits0[] = {
 #include "bitmaps/rew.button.small"
-	}, small_bits1[] = {
 #include "bitmaps/play.button.small"
-	}, small_bits2[] = {
 #include "bitmaps/ff.button.small"
-	}, small_bits3[] = {
 #include "bitmaps/pause.button.small"
-	}, small_bits4[] = {
 #include "bitmaps/stop.button.small"
-	}, small_bits5[] = {
 #include "bitmaps/eject.button.small"
-	};
 
 	if ((ip = (window1_objects *) calloc(1,
 				sizeof(window1_objects))) == NULL)
 		return (NULL);
 
 	image = xv_create(XV_NULL, SERVER_IMAGE, SERVER_IMAGE_DEPTH, 1,
-		SERVER_IMAGE_BITS, bits, XV_WIDTH, 64, XV_HEIGHT, 64,
+		SERVER_IMAGE_X_BITS, icon_bits, XV_WIDTH, 64, XV_HEIGHT, 64,
 		NULL);
 	image_mask = xv_create(XV_NULL, SERVER_IMAGE, SERVER_IMAGE_DEPTH,
-		1, SERVER_IMAGE_BITS, mask_bits, XV_WIDTH, 64,
+		1, SERVER_IMAGE_X_BITS, iconmask_bits, XV_WIDTH, 64,
 		XV_HEIGHT, 64, NULL);
 	ip->window1 = xv_create(owner, FRAME, XV_KEY_DATA, INSTANCE,
 		ip, XV_LABEL, "WorkMan", FRAME_SHOW_FOOTER, FALSE,
@@ -172,7 +156,7 @@ window1_objects_init(ip, owner)
 
 	speaker_image = xv_create(XV_NULL, SERVER_IMAGE,
 		SERVER_IMAGE_DEPTH, 1,
-		SERVER_IMAGE_BITS, speaker_bits,
+		SERVER_IMAGE_X_BITS, loud_bits,
 		XV_WIDTH, 16,
 		XV_HEIGHT, 15,
 		NULL);
@@ -196,37 +180,43 @@ window1_objects_init(ip, owner)
 
 	mode_image0 = xv_create(XV_NULL, SERVER_IMAGE,
 		SERVER_IMAGE_DEPTH, 1,
-		SERVER_IMAGE_BITS, small_buttons ? small_bits0 : mode_bits0,
+		SERVER_IMAGE_X_BITS, small_buttons ?
+			rew_button_small_bits : rew_button_bits,
 		XV_WIDTH, small_buttons ? 16 : 32,
 		XV_HEIGHT, 16,
 		NULL);
 	mode_image1 = xv_create(XV_NULL, SERVER_IMAGE,
 		SERVER_IMAGE_DEPTH, 1,
-		SERVER_IMAGE_BITS, small_buttons ? small_bits1 : mode_bits1,
+		SERVER_IMAGE_X_BITS, small_buttons ?
+			play_button_small_bits : play_button_bits,
 		XV_WIDTH, small_buttons ? 16 : 32,
 		XV_HEIGHT, 16,
 		NULL);
 	mode_image2 = xv_create(XV_NULL, SERVER_IMAGE,
 		SERVER_IMAGE_DEPTH, 1,
-		SERVER_IMAGE_BITS, small_buttons ? small_bits2 : mode_bits2,
+		SERVER_IMAGE_X_BITS, small_buttons ?
+			ff_button_small_bits : ff_button_bits,
 		XV_WIDTH, small_buttons ? 16 : 32,
 		XV_HEIGHT, 16,
 		NULL);
 	mode_image3 = xv_create(XV_NULL, SERVER_IMAGE,
 		SERVER_IMAGE_DEPTH, 1,
-		SERVER_IMAGE_BITS, small_buttons ? small_bits3 : mode_bits3,
+		SERVER_IMAGE_X_BITS, small_buttons ?
+			pause_button_small_bits : pause_button_bits,
 		XV_WIDTH, small_buttons ? 16 : 32,
 		XV_HEIGHT, 16,
 		NULL);
 	mode_image4 = xv_create(XV_NULL, SERVER_IMAGE,
 		SERVER_IMAGE_DEPTH, 1,
-		SERVER_IMAGE_BITS, small_buttons ? small_bits4 : mode_bits4,
+		SERVER_IMAGE_X_BITS, small_buttons ?
+			stop_button_small_bits : stop_button_bits,
 		XV_WIDTH, small_buttons ? 16 : 32,
 		XV_HEIGHT, 16,
 		NULL);
 	mode_image5 = xv_create(XV_NULL, SERVER_IMAGE,
 		SERVER_IMAGE_DEPTH, 1,
-		SERVER_IMAGE_BITS, small_buttons ? small_bits5 : mode_bits5,
+		SERVER_IMAGE_X_BITS, small_buttons ?
+			eject_button_small_bits : eject_button_bits,
 		XV_WIDTH, small_buttons ? 16 : 32,
 		XV_HEIGHT, 16,
 		NULL);
@@ -290,10 +280,19 @@ window1_objects_init(ip, owner)
 		PANEL_NOTIFY_PROC, window1_button3_notify_callback,
 		NULL);
 
+/*
+	ip->dbmenu = xv_create(NULL, MENU,
+		MENU_ACTION_ITEM, "This CD...", show_cdinfo,
+		MENU_ACTION_ITEM, "Preferences...", show_db_prefs,
+		NULL);
+*/
+
 	ip->button2 = xv_create(ip->controls1, PANEL_BUTTON,
 		XV_HELP_DATA, "workman:button2",
 		PANEL_LABEL_STRING, "CD Info...",
-		PANEL_NOTIFY_PROC, window1_button2_notify_callback,
+/*
+		PANEL_ITEM_MENU, ip->dbmenu,
+*/		PANEL_NOTIFY_PROC, show_cdinfo,
 		NULL);
 	
 	ip->button4 = xv_create(ip->controls1, PANEL_BUTTON,
@@ -525,10 +524,19 @@ popup1_objects_init(ip, owner)
 		PANEL_NOTIFY_PROC, set_default_volume,
 		NULL);
 
+	/* This will get changed to an image later, but use text for now */
 	ip->defaultspeaker = xv_create(ip->controls2, PANEL_MESSAGE,
 		XV_HELP_DATA, "workman:defaultspeaker",
 		PANEL_LABEL_STRING, "None",
 		PANEL_LABEL_BOLD, FALSE,
+		XV_SHOW, FALSE,
+		NULL);
+
+	ip->nonemsg = xv_create(ip->controls2, PANEL_MESSAGE,
+		XV_HELP_DATA, "workman:defaultspeaker",
+		PANEL_LABEL_STRING, "None",
+		PANEL_LABEL_BOLD, FALSE,
+		XV_X, xv_get(ip->defaultspeaker, XV_X),
 		NULL);
 
 	space = wid(ip->whichvolume) + wid(ip->defaultspeaker) * 2 +
@@ -557,6 +565,9 @@ popup1_objects_init(ip, owner)
 	xv_set(ip->defaultspeaker, XV_X, rig(ip->defaultvolume) + 5,
 		XV_Y, top(ip->defaultspeaker) + hei(ip->defaultvolume) / 6,
 		NULL);
+	xv_set(ip->nonemsg, XV_X, xv_get(ip->defaultspeaker, XV_X),
+		XV_Y, xv_get(ip->defaultspeaker, XV_Y),
+		NULL);
 
 	ip->playmode = xv_create(ip->controls2, PANEL_CHOICE,
 		XV_HELP_DATA, "workman:playmode",
@@ -630,9 +641,7 @@ about_objects_init(ip, owner)
 	Panel_item	item;
 	int		space;
 	Xv_opaque               sink_image, message7_image;
-	static unsigned short   sink_bits[] = {
 #include "bitmaps/sink0"
-	};
 
 	if ((ip = (about_objects *) calloc(1,
 				sizeof(about_objects))) == NULL)
@@ -658,7 +667,11 @@ about_objects_init(ip, owner)
 
 	ip->message1 = xv_create(ip->controls3, PANEL_MESSAGE,
 		XV_Y, 8,
-		PANEL_LABEL_STRING, "WorkMan 1.2",
+#ifdef SBPCD_HACK
+		PANEL_LABEL_STRING, "WorkMan 1.3a mB",
+#else
+		PANEL_LABEL_STRING, "WorkMan 1.3a",
+#endif
 		PANEL_LABEL_BOLD, TRUE, NULL);
 	ip->message2 = xv_create(ip->controls3, PANEL_MESSAGE,
 		PANEL_LABEL_STRING, "\"The Civilized CD Player\"",
@@ -666,7 +679,7 @@ about_objects_init(ip, owner)
 
 	message7_image = xv_create(XV_NULL, SERVER_IMAGE,
 		SERVER_IMAGE_DEPTH, 1,
-		SERVER_IMAGE_BITS, bits,
+		SERVER_IMAGE_X_BITS, icon_bits,
 		XV_WIDTH, 64,
 		XV_HEIGHT, 64,
 		NULL);
@@ -678,7 +691,7 @@ about_objects_init(ip, owner)
 
 	sink_image = xv_create(XV_NULL, SERVER_IMAGE,
 		SERVER_IMAGE_DEPTH, 1,
-		SERVER_IMAGE_BITS, sink_bits,
+		SERVER_IMAGE_X_BITS, sink0_bits,
 		XV_WIDTH, 64,
 		XV_HEIGHT, 64,
 		NULL);
@@ -692,13 +705,13 @@ about_objects_init(ip, owner)
 		PANEL_LABEL_STRING, "Written by Steven Grimm",
 		PANEL_LABEL_BOLD, TRUE, NULL);
 	ip->message4 = xv_create(ip->controls3, PANEL_MESSAGE,
-		PANEL_LABEL_STRING, "koreth@Hyperion.COM",
+		PANEL_LABEL_STRING, "koreth@midwinter.com",
 		PANEL_LABEL_BOLD, FALSE, NULL);
 	ip->message5 = xv_create(ip->controls3, PANEL_MESSAGE,
-		PANEL_LABEL_STRING, "Send mail if you'd like to be",
+		PANEL_LABEL_STRING, "Maintained by Dirk Foersterling",
 		PANEL_LABEL_BOLD, FALSE, NULL);
 	ip->message6 = xv_create(ip->controls3, PANEL_MESSAGE,
-		PANEL_LABEL_STRING, "notified of future revisions!",
+		PANEL_LABEL_STRING, "see DOCS/CONTACT for details",
 		PANEL_LABEL_BOLD, FALSE, NULL);
 
 	ip->drive = xv_create(ip->controls3, PANEL_MESSAGE,
@@ -766,9 +779,7 @@ goodies_objects_init(ip, owner)
 {
 	Panel_item	item;
 	Xv_opaque	phones_image;
-	static unsigned short phones_bits[] = {
 #include "bitmaps/phones0"
-	};
 	int		space;
 
 	if ((ip = (goodies_objects *) calloc(1,
@@ -811,7 +822,7 @@ goodies_objects_init(ip, owner)
 
 	phones_image = xv_create(XV_NULL, SERVER_IMAGE,
 		SERVER_IMAGE_DEPTH, 1,
-		SERVER_IMAGE_BITS, phones_bits,
+		SERVER_IMAGE_X_BITS, phones0_bits,
 		XV_WIDTH, 16,
 		XV_HEIGHT, 22,
 		NULL);
@@ -1093,3 +1104,39 @@ plpopup_objects_init(ip, owner)
 
 	return (ip);
 }
+
+/*
+ * Create the database preferences window and its contents.
+db_prefs_objects *
+db_prefs_init(ip, owner)
+	db_prefs_objects	*ip;
+	Xv_opaque		owner;
+{
+	if ((ip = (db_prefs_objects *) calloc(1,
+				sizeof(db_prefs_objects))) == NULL)
+		return (NULL);
+	
+	ip->window = xv_create(owner, FRAME_CMD,
+		XV_KEY_DATA, INSTANCE, ip,
+		XV_LABEL, "Databases",
+		XV_SHOW, FALSE,
+		FRAME_SHOW_FOOTER, FALSE,
+		FRAME_SHOW_RESIZE_CORNER, TRUE,
+		FRAME_CMD_PUSHPIN_IN, FALSE,
+		NULL);
+	
+	ip->panel = xv_get(ip->window, FRAME_CMD_PANEL);
+	xv_set(ip->panel,
+		XV_KEY_DATA, INSTANCE, ip,
+		XV_HELP_DATA, "workman:dbprefs-panel",
+		XV_X, 0,
+		XV_Y, 0,
+		WIN_BORDER, FALSE,
+		NULL);
+	
+	ip->filelist = xv_create(ip->panel, PANEL_LIST,
+		XV_HELP_DATA, "workman:dbprefs-filelist",
+		XV_X, 6,
+		XV_Y, 8,
+		PANEL_LIST_WIDTH, basic_spacing * 40
+ */
