@@ -1,4 +1,4 @@
-/* @(#)struct.h	1.16 12/21/93 */
+/* @(#)struct.h	1.17 2/24/94 */
 
 /*
  * Structure for a single track.  This is pretty much self-explanatory --
@@ -87,8 +87,8 @@ enum cd_modes	{
  */
 struct wm_drive {
 	int	fd;		/* File descriptor, if used by platform */
-	char	*vendor;	/* Vendor name */
-	char	*model;		/* Drive model */
+	char	vendor[16];	/* Vendor name */
+	char	model[24];	/* Drive model */
 	void	*aux;		/* Pointer to optional platform-specific info */
 	void	*daux;		/* Pointer to optional drive-specific info */
 
