@@ -1,9 +1,9 @@
 /*
- * @(#)ui_cdinfo.c	1.5	12/18/93
+ * @(#)ui_cdinfo.c	1.8	16 Jun 1995
  *
  * ui_cdinfo.c - handle the user interface elements in the CD Info popup.
  */
-static char *ident = "@(#)ui_cdinfo.c	1.5 12/18/93";
+static char *ident = "@(#)ui_cdinfo.c	1.8 16 Jun 1995";
 
 #include <stdio.h>
 #include <sys/param.h>
@@ -52,7 +52,7 @@ extern int displayed_track, pop_track, *pop_list, pop_listsize, pl_item,
 extern char *empty;
 extern int dont_retry, dismiss_button, info_modified;
 extern void (*text_event_handler)();
-extern unsigned short speaker_bits[][15];
+extern unsigned char *speaker_bits[];
 
 /*
  * Stash the current settings away in memory (in preparation for changing
@@ -319,16 +319,22 @@ set_default_volume(item, value, event)
 	{
 		xv_set(ip->defaultspeaker, PANEL_LABEL_IMAGE,
 			xv_create(XV_NULL, SERVER_IMAGE, SERVER_IMAGE_DEPTH, 1,
-			XV_WIDTH, 16, XV_HEIGHT, 15, SERVER_IMAGE_BITS,
+			XV_WIDTH, 16, XV_HEIGHT, 15, SERVER_IMAGE_X_BITS,
 			speaker_bits[new_image], NULL), NULL);
-		if (old_image > 0)
+		if (old_image > -1)
 			xv_destroy(old_serverimage);
+		else
+		{
+			xv_set(ip->nonemsg, XV_SHOW, FALSE, NULL);
+			xv_set(ip->defaultspeaker, XV_SHOW, TRUE, NULL);
+		}
 		old_image = new_image;
 	}
 	if (new_image != old_image && new_image == -1)
 	{
 		xv_destroy(old_serverimage);
-		xv_set(ip->defaultspeaker, PANEL_LABEL_STRING, "None", NULL);
+		xv_set(ip->defaultspeaker, XV_SHOW, FALSE, NULL);
+		xv_set(ip->nonemsg, XV_SHOW, TRUE, NULL);
 		old_image = -1;
 	}
 }
