@@ -1,10 +1,10 @@
 /*
- * @(#)workman_stubs.c	1.134	4/8/94
+ * @(#)workman_stubs.c	1.142	16 Jun 1995
  *
  * workman_stubs.c - Notify and event callback function stubs.
  */
 
-static char *ident = "@(#)workman_stubs.c	1.134\t4/8/94";
+static char *ident = "@(#)workman_stubs.c	1.142\t16 Jun 1995";
 
 #include <stdio.h>
 #include <sys/param.h>
@@ -49,7 +49,7 @@ int	switch_playlists();
 void	stop_repeating();
 Notify_value check_open(), byebye(), sigusr1(), sigusr2(), sigquit(),
 	sigttin(), sigttou(), sigemt();
-void	window1_button2_notify_callback(),
+void	show_cdinfo(),
 	popup1_buttonpl_notify_callback(),
 	window1_button4_notify_callback(),
 	window1_button3_notify_callback();
@@ -66,6 +66,7 @@ int	confirmsave;
 int	add_height, small_height;
 int	min_lines = -1;
 int	dont_retry = 0;
+int	reverse_threshold = 2;
 void	(*text_event_handler)();
 
 window1_objects	*Workman_window1;
@@ -124,13 +125,13 @@ main(argc, argv)
         extern char     *optarg, *rcfile, *dbfiles;
 	extern int	keep_open;
 
-#ifdef SVR4
+#if defined(SVR4) && !defined(__sony_news) /* { */
         if (setreuid(-1, getuid()) < 0)
         {
                 perror("setreuid");
                 exit(-1);
         }
-#endif
+#endif /* } */
         
 	/*
 	 * Initialize XView.
@@ -156,6 +157,9 @@ main(argc, argv)
 	if (dbfiles)
 		dbfiles = WMstrdup(dbfiles);
 
+	reverse_threshold = defaults_get_integer("workman.reverseThreshold",
+		"Workman.ReverseThreshold", reverse_threshold);
+
 	while ((c = getopt(argc, argv, "s:p:dc:ol:eXnbV:hCD:")) != EOF)
 		switch (c) {
 		case 'p':
@@ -211,7 +215,7 @@ main(argc, argv)
   -d  don't display title information\n\
   -D  filename(s) of global database\n\
   -e  don't check for CD insertion when no CD is present\n\
-  -h  display this message\n", argv[0], cd_device);
+  -h  display this message\n", argv[0], cd_device ? cd_device : "[none]");
 			fprintf(stderr,
 "  -l  leave room for at least N lines of track title\n\
   -n  don't use file locking when updating database (dangerous)\n\
@@ -271,7 +275,7 @@ main(argc, argv)
 		xv_create(Workman_popup1->controls2, PANEL_BUTTON,
 			XV_X, 10, XV_Y, (int) xv_get(Workman_popup1->buttonpl,
 			XV_Y), PANEL_LABEL_STRING, "Dismiss", PANEL_NOTIFY_PROC,
-			window1_button2_notify_callback, NULL);
+			show_cdinfo, NULL);
 #define ip Workman_window1
 		/* Squish the main window buttons down some. */
 		quitbutton = xv_create(ip->controls1, PANEL_BUTTON,
@@ -399,23 +403,19 @@ main(argc, argv)
 
 static int time_wanted = -1;
 
-static unsigned short sink_bits[8][64 * 16] = { {
 #include "bitmaps/sink0"
-}, {
 #include "bitmaps/sink1"
-}, {
 #include "bitmaps/sink2"
-}, {
 #include "bitmaps/sink3"
-}, {
 #include "bitmaps/sink4"
-}, {
 #include "bitmaps/sink5"
-}, {
 #include "bitmaps/sink6"
-}, {
 #include "bitmaps/sink7"
-} };
+
+static unsigned char *sink_bits[8] = { 
+	sink0_bits, sink1_bits, sink2_bits, sink3_bits,
+	sink4_bits, sink5_bits, sink6_bits, sink7_bits
+};
 
 /*
  * Timer handler.  This is called twice a second and updates the clocks and
@@ -468,7 +468,8 @@ int		w;
 		old_image = xv_get(Workman_about->sink, PANEL_LABEL_IMAGE);
 		xv_set(Workman_about->sink, PANEL_LABEL_IMAGE,
 			xv_create(XV_NULL, SERVER_IMAGE, SERVER_IMAGE_DEPTH, 1,
-				XV_WIDTH, 64, XV_HEIGHT, 64, SERVER_IMAGE_BITS,
+				XV_WIDTH, 64, XV_HEIGHT, 64,
+				SERVER_IMAGE_X_BITS,
 				sink_bits[new_image], NULL), NULL);
 		xv_destroy(old_image);
 		new_image = (new_image + 1) & 7;
@@ -717,8 +718,13 @@ change_mode(item, value, event)
 	case 0:		/* back a track */
 		if (cur_cdmode == PLAYING)
 		{
-			play_prev_track();
-			cd_status();
+			if (cur_pos_rel >= reverse_threshold)
+				time_wanted = 0;
+			else
+			{
+				play_prev_track();
+				cd_status();
+			}
 		}
 		else if (cur_track > 1)
 		{
@@ -869,7 +875,7 @@ stopped:
  * Notify callback function for `button2'.  Show the CD Info popup.
  */
 void
-window1_button2_notify_callback(item, event)
+show_cdinfo(item, event)
 	Panel_item	item;
 	Event		*event;
 {
@@ -914,7 +920,7 @@ window1_button2_notify_callback(item, event)
 				window1, XV_Y) - 25, NULL);
 	}
 	
-	if (dismiss_button && item == ip->button2 ||
+	if (dismiss_button && item == ip->dbmenu ||
 		xv_get(Workman_popup1->popup1, FRAME_CMD_PUSHPIN_IN) == FALSE)
 	{
 		xv_set(Workman_popup1->popup1, FRAME_CMD_PUSHPIN_IN, TRUE,
@@ -989,7 +995,7 @@ change_pos(item, value, event)
 {
 	char	time[6];
 	int	value_left;
-	
+
 	time_wanted = value;
 
 	if (cur_cdmode == STOPPED && cur_track > 0)
@@ -1070,23 +1076,19 @@ playlist_notify(item, string, client_data, op, event, row)
 	return XV_OK;
 }
 
-unsigned short speaker_bits[8][15] = { {
 #include "bitmaps/loud0.icon"
-}, {
 #include "bitmaps/loud1.icon"
-}, {
 #include "bitmaps/loud2.icon"
-}, {
 #include "bitmaps/loud3.icon"
-}, {
 #include "bitmaps/loud4.icon"
-}, {
 #include "bitmaps/loud5.icon"
-}, {
 #include "bitmaps/loud6.icon"
-}, {
 #include "bitmaps/loud.icon"
-} };
+
+unsigned char *speaker_bits[8] = {
+	loud0_bits, loud1_bits, loud2_bits, loud3_bits,
+	loud4_bits, loud5_bits, loud6_bits, loud_bits
+};
 
 /*
  * Notify callback function for `volume'.
@@ -1117,7 +1119,7 @@ set_volume(item, value, event)
 		old_serverimage = xv_get(ip->speaker, PANEL_LABEL_IMAGE);
 		xv_set(ip->speaker, PANEL_LABEL_IMAGE, xv_create(XV_NULL,
 			SERVER_IMAGE, SERVER_IMAGE_DEPTH, 1, XV_WIDTH, 16,
-			XV_HEIGHT, 15, SERVER_IMAGE_BITS,
+			XV_HEIGHT, 15, SERVER_IMAGE_X_BITS,
 			speaker_bits[new_image], NULL), NULL);
 		xv_destroy(old_serverimage);
 		old_image = new_image;
@@ -1194,21 +1196,18 @@ window1_button4_notify_callback(item, event)
 			XV_SHOW, FALSE, NULL);
 }
 
-static unsigned short phone_bits[7][22] = { {
 #include "bitmaps/phonesl3"
-}, {
 #include "bitmaps/phonesl2"
-}, {
 #include "bitmaps/phonesl1"
-}, {
 #include "bitmaps/phones0"
-}, {
 #include "bitmaps/phonesr1"
-}, {
 #include "bitmaps/phonesr2"
-}, {
 #include "bitmaps/phonesr3"
-} };
+
+static unsigned char *phone_bits[7] = {
+	phonesl3_bits, phonesl2_bits, phonesl1_bits, phones0_bits,
+	phonesr1_bits, phonesr2_bits, phonesr3_bits
+};
 
 /*
  * Notify callback function for `balance'.
@@ -1235,7 +1234,7 @@ slide_balance(item, value, event)
 		old_serverimage = xv_get(ip->phones, PANEL_LABEL_IMAGE);
 		xv_set(ip->phones, PANEL_LABEL_IMAGE, xv_create(XV_NULL,
 			SERVER_IMAGE, SERVER_IMAGE_DEPTH, 1, XV_WIDTH, 16,
-			XV_HEIGHT, 22, SERVER_IMAGE_BITS,
+			XV_HEIGHT, 20, SERVER_IMAGE_X_BITS,
 			phone_bits[new_image], NULL), NULL);
 		xv_destroy(old_serverimage);
 		old_image = new_image;
