@@ -2,7 +2,7 @@
 #define	HEADER
 
 /*
- * @(#)workman_ui.h	1.10 12/19/93
+ * @(#)workman_ui.h	1.12 03 Jun 1995
  *
  * User interface structure declarations.
  */
@@ -29,6 +29,7 @@ typedef struct {
 	Xv_opaque	button3;
 	Xv_opaque	button2;
 	Xv_opaque	button4;
+	Xv_opaque	dbmenu;
 } window1_objects;
 
 extern window1_objects	*window1_objects_init();
@@ -44,6 +45,7 @@ typedef struct {
 	Xv_opaque	whichvolume;
 	Xv_opaque	defaultvolume;
 	Xv_opaque	defaultspeaker;
+	Xv_opaque	nonemsg;
 	Xv_opaque	playmode;
 	Xv_opaque	autoplay;
 	Xv_opaque	button1;
@@ -103,4 +105,21 @@ typedef struct {
 
 extern plpopup_objects	*plpopup_objects_init();
 
+typedef struct {
+	Xv_opaque	window;
+	Xv_opaque	panel;
+
+	Xv_opaque	filelist;
+	Xv_opaque	personal;
+	Xv_opaque	server;
+	Xv_opaque	serversave;
+	Xv_opaque	fuzz;
+
+	Xv_opaque	apply;
+	Xv_opaque	reset;
+	Xv_opaque	dismiss;
+} db_prefs_objects;
+
+extern db_prefs_objects	*db_prefs_init();
+
 #endif
